Crate ofiles

Structs

  • The Error type.
  • Newtype pattern to avoid type errors. https://www.gnu.org/software/libc/manual/html_node/Process-Identification.html

Enums

Traits

  • Additional methods for Result, for easy interaction with this crate.

Functions

  • Given a file path, return the process id of any processes that have an open file descriptor pointing to the given file.

Type Aliases

  • Convenient wrapper around std::Result.